import i18next from "i18next";
import { pullRecourse } from "./i18nPull";
import { initReactI18next } from "react-i18next";
declare module "i18next" {
  interface i18n {
    initI18n: (
      url: string,
      locales?: string | string[],
      defaultLang?: string
    ) => Promise<i18n>;
  }
}
i18next.initI18n = async function (
  url: string,
  locales?: string | string[],
  defaultLang?: string
) {
  // 默认拉取的语言
  if (!locales) {
    locales = [
      "zh-CN",
      "en-US",
      "ar-EG",
      "de-DE",
      "el-GR",
      "es-ES",
      "fr-FR",
      "in-ID",
      "ja-JP",
      "ko-KR",
      "th-TH",
      "vi-VN",
      "zh-TW",
    ];
  }
  try {
    const result = await pullRecourse(url, locales);
    const { nestedConfig, flagConfig } = nestedLanguageConfig(result);
    const localeMap = { ...flagConfig, ...nestedConfig };
    const language = defaultLang || "en-US";

    await i18next.use(initReactI18next).init({
      lng: language,
      resources: localeMap,
      interpolation: {
        escapeValue: false,
      },
    });

    console.log("i18n 初始化成功");
    return i18next;
  } catch (error) {
    console.error("i18n 初始化失败:", error);
    throw error;
  }
};

// 扁平化处理函数
const nestedLanguageConfig = (data: any) => {
  const nestedConfig = {} as Record<any, any>;
  const flagConfig = {} as Record<any, any>;
  Object.keys(data).forEach((flatKey) => {
    if (!isHaveNamespace(flatKey)) {
      flagConfig[flatKey] = data[flatKey];
      return;
    }

    const [module, key] = flatKey.split(":");
    if (!nestedConfig.hasOwnProperty(module)) {
      nestedConfig[module] = {};
    }
    nestedConfig[module][key] = data[flatKey];
  });
  return { nestedConfig, flagConfig };
};

// 检查是否需要修改格式
const isHaveNamespace = (key: string) => {
  return /[\s]*\w*[\s]*:/.test(key);
};

export { i18next };
