import axios from "axios";

// 创建 axios 实例
const request = axios.create({
  timeout: 5000, // 超时时间
  headers: {
    "Content-Type": "application/json",
  },
});

// 请求拦截器
request.interceptors.request.use(
  (config: any) => {
    return config;
  },
  (error: any) => {
    // 对请求错误做些什么
    console.error("请求错误:", error);
    return Promise.reject(error);
  }
);

// 响应拦截器
request.interceptors.response.use(
  (response: any) => {
    // 对响应数据做点什么
    const { data } = response;
    return data;
  },
  (error: any) => {
    // 对响应错误做点什么
    if (error.response) {
      const { status } = error.response;
      switch (status) {
        case 401:
          console.error("未授权");
          break;
        case 403:
          console.error("拒绝访问");
          break;
        case 404:
          console.error("请求地址不存在");
          break;
        case 500:
          console.error("服务器内部错误");
          break;
        default:
          console.error(`请求失败: ${status}`);
      }
    }
    return Promise.reject(error);
  }
);

export default request;
